#!/usr/bin/env python

from query import qfilter
qf = qfilter

__all__ = ['qf', 'qfilter']
